unit fmChartTest;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, VclTee.TeEngine, VclTee.Series, Vcl.ExtCtrls,
  VclTee.TeeProcs, VclTee.Chart, Vcl.StdCtrls, dxGDIPlusClasses, cxGraphics, cxControls, cxLookAndFeels,
  cxLookAndFeelPainters, cxContainer, cxEdit, dxSkinsCore, Softdrill_NL, cxImage, cxLabel;

type
  TForm1 = class(TForm)
    btnCopy: TButton;
    imgChart: TImage;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnCopyClick(Sender: TObject);
  private
    { Private declarations }
    FChartMem: TChart;
    procedure SetupChart;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.btnCopyClick(Sender: TObject);
var
  myRect: TRect;
begin
  // Determine the rectangle (to paint to) we need...
  myRect := imgChart.ClientRect;
  // Adjust rectangle...
  InflateRect(myRect, FChartMem.Axes.Right.MaxLabelsWidth + FChartMem.Axes.Right.TickLength,
    Abs(FChartMem.Axes.Bottom.LabelsFont.Height) + FChartMem.Axes.Bottom.TickLength);

  // Resize the chart
  FChartMem.CustomChartRect := true;
  FChartMem.ChartRect := myRect;
  SetupChart;
  FChartMem.Invalidate;

  // Obtain the chartrect as bitmap
  myRect := imgChart.ClientRect;
  imgChart.Picture.Bitmap := FChartMem.TeeCreateBitmap(clWhite, myRect);

  // Highlight the TImage boundaries
  imgChart.Picture.Bitmap.Canvas.Pen.Color := clRed;
  imgChart.Picture.Bitmap.Canvas.Brush.Style := bsClear;
  imgChart.Picture.Bitmap.Canvas.Rectangle(imgChart.ClientRect);
end;

procedure TForm1.FormCreate(Sender: TObject);
var
  mySeries: TChartSeries;
begin
  FChartMem := TChart.Create(nil);
  FChartMem.Parent := nil;

  FChartMem.FreeAllSeries;
  mySeries := FChartMem.AddSeries(TLineSeries);
  mySeries.VertAxis := aRightAxis;
  mySeries.HorizAxis := aBottomAxis;
  mySeries.FillSampleValues(30);

  SetupChart;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  FChartMem.FreeAllSeries;
  FChartMem.Free;
end;

procedure TForm1.SetupChart;
begin
  FChartMem.View3D := false;
  FChartMem.Legend.Visible := false;
  FChartMem.Color := clWhite;

  FChartMem.BackWall.Frame.Visible := false;
  FChartMem.BackWall.Gradient.Visible := false;
  FChartMem.BackWall.Color := clWhite;
  FChartMem.BackWall.Transparent := false;

  FChartMem.Axes.Right.Automatic := false;
  FChartMem.Axes.Right.Minimum := 0;
  FChartMem.Axes.Right.Maximum := 1000;
  FChartMem.Axes.Right.Inverted := true;
  FChartMem.Axes.Right.PositionPercent := 100;
  FChartMem.Axes.Right.LabelsOnAxis := false;
  FChartMem.Axes.Right.Visible := true;
  FChartMem.Axes.Right.Axis.Visible := false;
  FChartMem.Axes.Right.LabelsFormat.Visible := true;
  FChartMem.Axes.Right.Grid.DrawAlways := true;
  FChartMem.Axes.Right.MinimumOffset := 50;

  FChartMem.Axes.Bottom.Automatic := false;
  FChartMem.Axes.Bottom.Minimum := 0;
  FChartMem.Axes.Bottom.Maximum := 100;
  FChartMem.Axes.Bottom.PositionPercent := 100;
  FChartMem.Axes.Bottom.LabelsOnAxis := false;
  FChartMem.Axes.Bottom.Visible := true;
  FChartMem.Axes.Bottom.Axis.Visible := false;
  FChartMem.Axes.Bottom.LabelsFormat.Visible := true;
  FChartMem.Axes.Bottom.Grid.DrawAlways := true;
  FChartMem.Axes.Bottom.MinimumOffset := 50;
end;

end.
